@@ -10,14 +10,11 @@
 #' @returns S3 object of class `rigma_delete_comment`. Contains the parsed
 #' JSON response with fields `error`, `status`, and `i18n`.
 #'
-#' @importFrom httr2 request req_url_path_append req_headers req_user_agent
-#' req_perform resp_body_json req_url_query req_method
-#'
 #' @importFrom checkmate assert_string
 #'
 #' @examplesIf Sys.getenv("FIGMA_ACCESS_TOKEN") != ""
 #' \dontrun{
-#' #navigate to  file and get key from url
+#' # navigate to  file and get key from url
 #' file_key <- "sFHgQh9dL6369o5wrZHmdR"
 #' first_comment_id <- get_comments(file_key)$comments[[1]]$id
 #' delete_comment(file_key, first_comment_id)
@@ -28,22 +25,18 @@ delete_comment <- function(
     file_key,
     comment_id
 ) {
-  assert_string(file_key)
+  assert_file_key(file_key)
   assert_string(comment_id)
 
-  resp <- request("https://api.figma.com/v1/files/") %>%
-    req_url_path_append(file_key) %>%
-    req_url_path_append("comments") %>%
-    req_url_path_append(comment_id) %>%
-    req_method("DELETE") %>%
-    req_error(body = function(resp) {
-      resp %>%
-        resp_body_json() %>%
-        chuck("message")
-    }) %>%
-    req_rigma_agent %>%
-    req_perform() %>%
-    resp_body_json()
+  resp <- request_figma(
+    method = "DELETE",
+  ) %>%
+    req_figma_template(
+      endpoint = "comment delete",
+      file_key = file_key,
+      comment_id = comment_id
+    ) %>%
+    req_figma_perform()
 
   structure(
     list(
