@@ -7,11 +7,6 @@
 #' @returns S3 object of class `rigma_get_file_styles`. Styles are
 #' stored in the `meta` field.
 #'
-#' @importFrom httr2 request req_url_path_append req_headers req_user_agent
-#' req_perform resp_body_json req_url_query
-#'
-#' @importFrom checkmate assert_string
-#'
 #' @examplesIf Sys.getenv("FIGMA_ACCESS_TOKEN") != ""
 #' \dontrun{
 #' #navigate to team page and get id from url
@@ -21,19 +16,14 @@
 #'
 #' @export
 get_file_styles <- function(file_key) {
-  assert_string(file_key)
+  assert_file_key(file_key)
 
-  resp <- request("https://api.figma.com/v1/files/") %>%
-    req_url_path_append(file_key) %>%
-    req_url_path_append("styles") %>%
-    req_error(body = function(resp) {
-      resp %>%
-        resp_body_json() %>%
-        chuck("err")
-    }) %>%
-    req_rigma_agent %>%
-    req_perform() %>%
-    resp_body_json()
+  resp <- request_figma() %>%
+    req_figma_template(
+      "file styles",
+      file_key = file_key,
+      .perform = TRUE
+    )
 
   structure(
     list(
