@@ -14,11 +14,6 @@
 #' are located in the output of the GET files endpoint under the `imageRef`
 #' attribute in a Paint.
 #'
-#' @importFrom httr2 request req_url_path_append req_headers req_user_agent
-#' req_perform resp_body_json req_url_query
-#'
-#' @importFrom checkmate assert_string assert_integer assert_logical expect_list
-#'
 #' @examplesIf Sys.getenv("FIGMA_ACCESS_TOKEN") != ""
 #' \dontrun{
 #' #navigate to  file and get key from url
@@ -28,19 +23,14 @@
 #'
 #' @export
 get_image_fills <- function(file_key) {
-  assert_string(file_key)
+  assert_file_key(file_key)
 
-  resp <- request("https://api.figma.com/v1/files/") %>%
-    req_url_path_append(file_key) %>%
-    req_url_path_append("images") %>%
-    req_error(body = function(resp) {
-      resp %>%
-        resp_body_json() %>%
-        chuck("err")
-    }) %>%
-    req_rigma_agent %>%
-    req_perform() %>%
-    resp_body_json()
+  resp <- request_figma() %>%
+    req_figma_template(
+      "image fills",
+      file_key = file_key,
+      .perform = TRUE
+    )
 
   structure(
     list(
